parity.generate

Reflect on JVM, generate tests, capture reference, emit cljc.

Reflect on JVM, generate tests, capture reference, emit cljc.
raw docstring

*capture-threads*clj

source

*eval-timeout-ms*clj

source

-mainclj

(-main & args)
source

all-namespacesclj

source

arg-name-strclj

(arg-name-str arg)
source

arg-typeclj

(arg-type arg-name ns-name)

Infer value type from tag metadata, then arg name, then namespace context.

Infer value type from tag metadata, then arg name, then namespace context.
sourceraw docstring

base-dirclj

source

classify-varclj

(classify-var sym var-meta)
source

contrib-namespacesclj

source

default-namespacesclj

source

do-captureclj

(do-capture)
source

do-expandclj

(do-expand)
source

do-verifyclj

(do-verify)
source

effective-typeclj

(effective-type arg ns-name)

Get the effective type for an arg: tag metadata first, then name-based inference.

Get the effective type for an arg: tag metadata first, then name-based inference.
sourceraw docstring

emit-cljcclj

(emit-cljc output-path)
source

expand-spec-fileclj

(expand-spec-file path)
source

expressions-fileclj

source

gen-testsclj

(gen-tests sym var-meta ns-name)

Generate tests for a single var. Returns seq of {:it :eval} maps.

Generate tests for a single var. Returns seq of {:it :eval} maps.
sourceraw docstring

load-namespaces!clj

(load-namespaces! scope)
source

nilable-typesclj

Types where nil/empty are meaningful inputs (not just error-producing).

Types where nil/empty are meaningful inputs (not just error-producing).
sourceraw docstring

(print-stats results)
source

process-namespaceclj

(process-namespace ns-name)
source

reference-fileclj

source

results-dirclj

source

safe-evalclj

(safe-eval expr-str)
source

shipped-namespacesclj

source

skip-varsclj

Vars that can't be tested with simple expression eval.

Vars that can't be tested with simple expression eval.
sourceraw docstring

spec-dirsclj

source

spec-filesclj

(spec-files)
source

tag->typeclj

Map JVM type hints to our value types. nil = untestable (skip the var).

Map JVM type hints to our value types. nil = untestable (skip the var).
sourceraw docstring

tag-typeclj

(tag-type arg)

Get value type from arglist tag metadata. Returns :skip for untestable types.

Get value type from arglist tag metadata. Returns :skip for untestable types.
sourceraw docstring

test-values-forclj

(test-values-for arg ns-name)

Generate test value sets for an arg: [{:label suffix :val string}].

Generate test value sets for an arg: [{:label suffix :val string}].
sourceraw docstring

valuesclj

source

write-specsclj

(write-specs results lang-dir contrib-dir)
source

cljdoc builds & hosts documentation for Clojure/Script libraries