Rewrite JVM Clojure to portable Clojure. Uses roots (JVM reflection) to discover every host dependency, then applies systematic naming conventions to replace them via rewrite-clj AST walking.
Rewrite JVM Clojure to portable Clojure. Uses roots (JVM reflection) to discover every host dependency, then applies systematic naming conventions to replace them via rewrite-clj AST walking.
(jvm-metadata? zloc)Check if a metadata node contains JVM-specific type hints.
Check if a metadata node contains JVM-specific type hints.
(strip-inline-keys map-str)Remove :inline and :inline-arities from metadata map string.
Remove :inline and :inline-arities from metadata map string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |